@@ -7,7 +7,7 @@
 ################################################################################
 # Version
 from .__version__ import __version__
-from .featurewiz import featurewiz, FE_convert_all_object_columns_to_numeric
+from .featurewiz import featurewiz
 from .featurewiz import FE_split_one_field_into_many, FE_add_groupby_features_aggregated_to_dataframe
 from .featurewiz import FE_start_end_date_time_features
 from .featurewiz import classify_features
@@ -21,18 +21,20 @@ from .featurewiz import FE_kmeans_resampler, FE_find_and_cap_outliers, EDA_find_
 from .featurewiz import split_data_n_ways, FE_concatenate_multiple_columns
 from .featurewiz import FE_discretize_numeric_variables
 from .ml_models import simple_XGBoost_model, simple_LightGBM_model, complex_XGBoost_model, complex_LightGBM_model,data_transform
-from .sulo_models import SuloClassifier, SuloRegressor, get_class_weights, get_scale_pos_weight, print_sulo_accuracy
 from .my_encoders import My_LabelEncoder, Groupby_Aggregator, My_LabelEncoder_Pipe, Ranking_Aggregator, DateTime_Transformer
 from .my_encoders import Rare_Class_Combiner, Rare_Class_Combiner_Pipe, FE_create_time_series_features, Binning_Transformer
-from .my_encoders import TSLagging_Transformer
+from .my_encoders import TSLagging_Transformer, FE_convert_all_object_columns_to_numeric, Fourier_Transformer
+from .my_encoders import Column_Names_Transformer
+
 from .sulov_method import FE_remove_variables_using_SULOV_method
 from .featurewiz import FE_transform_numeric_columns_to_bins, FE_create_interaction_vars
 from .stacking_models import Stacking_Classifier, Blending_Regressor, Stacking_Regressor, stacking_models_list
-from .featurewiz import EDA_binning_numeric_column_displaying_bins, FE_add_lagged_targets_by_date_category
+from .featurewiz import EDA_binning_numeric_column_displaying_bins
 from .featurewiz import FE_convert_mixed_datatypes_to_string, FE_drop_rows_with_infinity
 from .featurewiz import EDA_find_remove_columns_with_infinity, FE_split_list_into_columns
-from .featurewiz import EDA_remove_special_chars, EDA_make_column_names_unique, FE_remove_commas_in_numerics
+from .featurewiz import EDA_remove_special_chars, FE_remove_commas_in_numerics
 from .featurewiz import EDA_randomly_select_rows_from_dataframe, remove_duplicate_cols_in_dataset
+
 from .featurewiz import FeatureWiz
 ################################################################################
 if __name__ == "__main__":
@@ -40,11 +42,10 @@ if __name__ == "__main__":
 else:
     module_type = 'Imported'
 version_number = __version__
-print("""%s version = %s.
-from featurewiz import FeatureWiz
-wiz = FeatureWiz(verbose=1)
-X_train_selected = wiz.fit_transform(X_train, y_train)
-X_test_selected = wiz.transform(X_test)
-wiz.features  ### provides a list of selected features ###
-                                """ %(module_type, version_number))
+print("""%s %s version. Select nrows to a small number when running on huge datasets.
+output = featurewiz(dataname, target, corr_limit=0.70, verbose=2, sep=',', 
+		header=0, test_data='',feature_engg='', category_encoders='',
+		dask_xgboost_flag=False, nrows=None)
+Create new features via 'feature_engg' flag : ['interactions','groupby','target']
+""" %(module_type, version_number))
 ################################################################################
